@@ -2,7 +2,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2009 Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2009/mm/dd, v3.000.019, collector.pl for ASNMTAP::Asnmtap::Applications::Collector
+# 2009/04/19, v3.000.020, collector.pl for ASNMTAP::Asnmtap::Applications::Collector
 # ----------------------------------------------------------------------------------------------------------
 
 use strict;
@@ -23,10 +23,10 @@ use Date::Calc qw(Delta_DHMS);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Time v3.000.019;
+use ASNMTAP::Time v3.000.020;
 use ASNMTAP::Time qw(&get_datetimeSignal &get_csvfiledate &get_csvfiletime &get_logfiledate &get_datetime &get_timeslot);
 
-use ASNMTAP::Asnmtap::Applications::Collector v3.000.019;
+use ASNMTAP::Asnmtap::Applications::Collector v3.000.020;
 use ASNMTAP::Asnmtap::Applications::Collector qw(:APPLICATIONS :COLLECTOR :DBCOLLECTOR);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -42,7 +42,7 @@ use vars qw($opt_H  $opt_M $opt_C $opt_W $opt_A $opt_N $opt_s $opt_S $opt_D $opt
 
 $PROGNAME       = "collector.pl";
 my $prgtext     = "Collector for the '$APPLICATION'";
-my $version     = do { my @r = (q$Revision: 3.000.019$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
+my $version     = do { my @r = (q$Revision: 3.000.020$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -51,6 +51,7 @@ my $dumphttp    = 'N';                                          # default
 my $debug       = 'F';                                          # default
 my $logging     = '<NIHIL>';                                    # default
 my $httpdump    = '<NIHIL>';                                    # default
+my $lockMySQL   = 0;                                            # default
 
 my $perfParseMethode = 'PULP';                           # 'AIP', default
 
@@ -330,26 +331,24 @@ sub do_crontab {
                 $suspentionTimeslotPersistentTrue = $suspentionTimeslotPersistentFalse = 0;
 
                 while( ($TactivationTimeslot, $TsuspentionTimeslot, $Tinstability, $Tpersistent) = $sth->fetchrow_array() ) {
-                  if ( $Tinstability == 1 ) {
-                    $instability = 1;
-                  } else {
-                    if ( $Tpersistent ) {
-                      if ( $firstRecordPersistentTrue ) {
-                        $firstRecordPersistentTrue = 0;
-                        $suspentionTimeslotPersistentTrue = int($TsuspentionTimeslot);
-                      }
+                  $instability = ( $Tinstability ) ? 1 : $instability;
 
-                      $activationTimeslotPersistentTrue = ($activationTimeslotPersistentTrue < int($TactivationTimeslot)) ? $activationTimeslotPersistentTrue : int($TactivationTimeslot);
-                      $suspentionTimeslotPersistentTrue = ($suspentionTimeslotPersistentTrue > int($TsuspentionTimeslot)) ? $suspentionTimeslotPersistentTrue : int($TsuspentionTimeslot);
-                    } else {
-                      if ( $firstRecordPersistentFalse ) {
-                        $firstRecordPersistentFalse = 0;
-                        $suspentionTimeslotPersistentFalse = int($TsuspentionTimeslot);
-                      }
-
-                      $activationTimeslotPersistentFalse = ($activationTimeslotPersistentFalse < int($TactivationTimeslot)) ? $activationTimeslotPersistentFalse : int($TactivationTimeslot);
-                      $suspentionTimeslotPersistentFalse = ($suspentionTimeslotPersistentFalse > int($TsuspentionTimeslot)) ? $suspentionTimeslotPersistentFalse : int($TsuspentionTimeslot);
+                  if ( $Tpersistent ) {
+                    if ( $firstRecordPersistentTrue ) {
+                      $firstRecordPersistentTrue = 0;
+                      $suspentionTimeslotPersistentTrue = int($TsuspentionTimeslot);
                     }
+
+                    $activationTimeslotPersistentTrue = ($activationTimeslotPersistentTrue < int($TactivationTimeslot)) ? $activationTimeslotPersistentTrue : int($TactivationTimeslot);
+                    $suspentionTimeslotPersistentTrue = ($suspentionTimeslotPersistentTrue > int($TsuspentionTimeslot)) ? $suspentionTimeslotPersistentTrue : int($TsuspentionTimeslot);
+                  } else {
+                    if ( $firstRecordPersistentFalse ) {
+                      $firstRecordPersistentFalse = 0;
+                      $suspentionTimeslotPersistentFalse = int($TsuspentionTimeslot);
+                    }
+
+                    $activationTimeslotPersistentFalse = ($activationTimeslotPersistentFalse < int($TactivationTimeslot)) ? $activationTimeslotPersistentFalse : int($TactivationTimeslot);
+                    $suspentionTimeslotPersistentFalse = ($suspentionTimeslotPersistentFalse > int($TsuspentionTimeslot)) ? $suspentionTimeslotPersistentFalse : int($TsuspentionTimeslot);
                   }
                 }
               }
@@ -827,9 +826,11 @@ sub insertEntryDBI {
   }
 
   if ($insertEntryDBI or $updateEntryDBI) {
-    if ($dbh and $rv) {
-      $lockString = 'LOCK TABLES ' .$SERVERTABLEVENTS. ' WRITE';
-      $dbh->do ( $lockString ) or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->do: $lockString");
+    if ($lockMySQL) {
+      if ($dbh and $rv) {
+        $lockString = 'LOCK TABLES ' .$SERVERTABLEVENTS. ' WRITE, ' .$SERVERTABLEVENTSCHNGSLGDT. ' WRITE';
+        $dbh->do ( $lockString ) or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->do: $lockString");
+      }
     }
 
     if ($dbh and $rv) {
@@ -842,11 +843,31 @@ sub insertEntryDBI {
         $insertString = 'INSERT INTO ' .$SERVERTABLEVENTS. ' SET uKey="' .$uniqueKey. '", test="' .$test. '", title="' .$title. '", status="' .$status. '", startDate="' .$startDate. '", startTime="' .$startTime.'", endDate="' .$endDate. '", endTime="' .$endTime. '", duration="' .$duration. '", statusMessage="' .$statusMessage. '", step="' .($interval*60). '", timeslot="' .get_timeslot ($currentDate). '", instability="' .$instability. '", persistent="' .$persistent. '", downtime="' .$downtime. '", filename="' .$filename. '"';
         $dbh->do ( $insertString ) or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->do: $insertString");
       }
+
+      my ( $lastStatus, $lastTimeslot, $prevStatus, $prevTimeslot ) = ( $status, get_timeslot ($currentDate), '', '' );
+      my $sql = "select SQL_NO_CACHE lastStatus, lastTimeslot from $SERVERTABLEVENTSCHNGSLGDT where uKey = '$uniqueKey'";
+      my $sth = $dbh->prepare( $sql ) or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->prepare: $sql");
+      $sth->execute() or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot sth->execute: $sql");
+
+      if ( $rv ) {
+        if ( $sth->rows ) {
+	      ($prevStatus, $prevTimeslot) = $sth->fetchrow_array() or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot sth->fetchrow_array: $sql");
+          $sth->finish() or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot sth->finish: $sql");
+          $updateString = 'UPDATE ' .$SERVERTABLEVENTSCHNGSLGDT. ' SET lastStatus="' .$lastStatus. '", lastTimeslot="' .$lastTimeslot. '", prevStatus="' .$prevStatus. '", prevTimeslot="' .$prevTimeslot. '" where uKey="' .$uniqueKey. '"';
+          $dbh->do ( $updateString ) or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->do: $updateString");
+        } else {
+          $insertString = 'INSERT INTO ' .$SERVERTABLEVENTSCHNGSLGDT. ' SET uKey="' .$uniqueKey. '", lastStatus="' .$lastStatus. '", lastTimeslot="' .$lastTimeslot. '", prevStatus="' .$prevStatus. '", prevTimeslot="' .$prevTimeslot. '"';
+          $dbh->do ( $insertString )  or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->do: $insertString");
+        }
+      }
     }
 
-    if ($dbh and $rv) {
-      $unlockString = 'UNLOCK TABLES';
-      $dbh->do ( $unlockString ) or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->do: $unlockString");
+
+    if ($lockMySQL) {
+      if ($dbh and $rv) {
+        $unlockString = 'UNLOCK TABLES';
+        $dbh->do ( $unlockString ) or $rv = errorTrapDBI($currentDate, $uniqueKey, $test, $title, $status, $startDate, $startTime, $endDate, $endTime, $duration, $statusMessage, $interval, $filename, "Cannot dbh->do: $unlockString");
+      }
     }
   }
 
@@ -878,7 +899,7 @@ sub errorTrapDBI {
   } else {
     print "Cannot open $tlogging-$msgCommand-$uniqueKey.sql to print debug information\n";
   }
- 
+
   $rvOpen = open(DEBUG,">>$tlogging-$msgCommand-$uniqueKey-sql-error.txt");
 
   if ($rvOpen) {
@@ -943,7 +964,7 @@ sub graphEntryDBI {
   $step          = $interval * 60;
   $lastTimeslot  = timelocal (0, (localtime)[1,2,3,4,5]);
   $firstTimeslot = $lastTimeslot - ($step * ($limitTest));
-  $findString    = "select SQL_NO_CACHE  duration, startTime, status, timeslot from $SERVERTABLEVENTS where uKey = '$uniqueKey' and step <> '0' and (timeslot between '$firstTimeslot' and '$lastTimeslot') order by id desc limit $limitTest";
+  $findString    = "select SQL_NO_CACHE duration, startTime, status, timeslot from $SERVERTABLEVENTS where uKey = '$uniqueKey' and step <> '0' and (timeslot between '$firstTimeslot' and '$lastTimeslot') order by id desc limit $limitTest";
   print "$findString\n" if ($debug eq 'T');
 
   # data en labels in array zetten
@@ -1150,4 +1171,3 @@ email to $SENDEMAILTO
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-
