@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2009 by Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2009/mm/dd, v3.000.019, snmptt-3.000.019-v5.0.x.sql
+# 2009/04/19, v3.000.020, snmptt-3.000.020-v5.0.x.sql
 # ---------------------------------------------------------------------------------------------------------
 
 create database if not exists `snmptt`;
